@@ -1135,10 +1135,13 @@ static void php_zip_object_free_storage(void *object TSRMLS_DC) /* {{{ */
 	}
 	if (intern->za) {
 		if (zip_close(intern->za) != 0) {
-			php_error_docref(NULL TSRMLS_CC, E_WARNING, "Cannot destroy the zip context");
-			return;
+#if LIBZIP_VERSION_MAJOR == 1 && LIBZIP_VERSION_MINOR == 3 && LIBZIP_VERSION_MICRO == 1
+			php_error_docref(NULL TSRMLS_CC, E_WARNING, "Cannot destroy the zip context: zip_close have failed");
+#else
+			php_error_docref(NULL TSRMLS_CC, E_WARNING, "Cannot destroy the zip context: %s", zip_strerror(intern->za));
+			zip_discard(intern->za);
+#endif
 		}
-		intern->za = NULL;
 	}
 
 	if (intern->buffers_cnt>0) {
